#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# Note that not necessarily every HTML tag will be made available in
# HtmlTags::BaseModule for the time being. For now I will only add
# tags that I commonly need to re-use in other projects. In the long
# run, I may just batch-generate the required tags, though. (28.04.2019)
# =========================================================================== #
# require 'html_tags/base/base_module.rb'
# include HtmlTags::BaseModule
# =========================================================================== #
require 'html_tags/individual_tags/a.rb'
require 'html_tags/individual_tags/div.rb'
require 'html_tags/individual_tags/form.rb'
require 'html_tags/individual_tags/li.rb'
require 'html_tags/individual_tags/h1.rb'
require 'html_tags/individual_tags/h2.rb'
require 'html_tags/individual_tags/h3.rb'
require 'html_tags/individual_tags/h4.rb'
require 'html_tags/individual_tags/h5.rb'
require 'html_tags/individual_tags/h6.rb'
require 'html_tags/individual_tags/html.rb'
require 'html_tags/individual_tags/ol.rb'
require 'html_tags/individual_tags/p.rb'
require 'html_tags/individual_tags/pre.rb'

module HtmlTags

module BaseModule # === HtmlTags::BaseModule

  # ========================================================================= #
  # === HtmlTags::BaseModule.is_on_roebe?
  # ========================================================================= #
  def self.is_on_roebe?
    ENV['IS_ROEBE'].to_s == '1'
  end

  # ========================================================================= #
  # === pre
  # ========================================================================= #
  def pre(
      i = '', css_class = '', the_id = '', css_style = '', &block
    )
    HtmlTags.pre(
      i, css_class, the_id, css_style, &block
    )
  end

  # ========================================================================= #
  # === li                                                           (li tag)
  # ========================================================================= #
  def li(
      i = '', optional_css_class = '', optional_id = '', optional_css_style = '', &block
    )
    HtmlTags.li(
      i, optional_css_class, optional_id, optional_css_style, &block
    )
  end

  # ========================================================================= #
  # === ol                                                           (ol tag)
  # ========================================================================= #
  def ol(
      i = '', optional_css_class = '', optional_id = '', optional_css_style = '', &block
    )
    HtmlTags.ol(
      i, optional_css_class, optional_id, optional_css_style, &block
    )
  end

  # ========================================================================= #
  # === h1
  # ========================================================================= #
  def h1(
      i = '', css_class = '', the_id = '', css_style = '', javascript_code = '', &block
    )
    HtmlTags.h1(
      i, css_class, the_id, css_style, javascript_code, &block
    )
  end

  # ========================================================================= #
  # === h2
  # ========================================================================= #
  def h2(
      i               = '',
      css_class       = '',
      the_id          = '',
      css_style       = '',
      javascript_code = '',
      &block
    )
    HtmlTags.h2(
      i, css_class, the_id, css_style, javascript_code, &block
    )
  end

  # ========================================================================= #
  # === h3
  # ========================================================================= #
  def h3(
      i = '', css_class = '', the_id = '', css_style = '', javascript_code = '', &block
    )
    HtmlTags.h3(
      i, css_class, the_id, css_style, javascript_code, &block
    )
  end

  # ========================================================================= #
  # === h4
  # ========================================================================= #
  def h4(
      i = '', css_class = '', the_id = '', css_style = '', javascript_code = '', &block
    )
    HtmlTags.h4(
      i, css_class, the_id, css_style, javascript_code, &block
    )
  end

  # ========================================================================= #
  # === h5
  # ========================================================================= #
  def h5(
      i = '', css_class = '', the_id = '', css_style = '', javascript_code = '', &block
    )
    HtmlTags.h5(
      i, css_class, the_id, css_style, javascript_code, &block
    )
  end

  # ========================================================================= #
  # === h6
  # ========================================================================= #
  def h6(
      i = '', css_class = '', the_id = '', css_style = '', javascript_code = '', &block
    )
    HtmlTags.h6(
      i, css_class, the_id, css_style, javascript_code, &block
    )
  end

  # ========================================================================= #
  # === p
  #
  # This method can be used to create the html <p> tag.
  # ========================================================================= #
  def p(
      i         = '',
      css_class = '',
      the_id    = '',
      css_style = '',
      &block
    )
    HtmlTags.p(i, css_class, the_id, css_style, &block)
  end

  # ========================================================================= #
  # === div
  #
  # This method can be used to create the html <div> tag.
  # ========================================================================= #
  def div(
      i         = '',
      css_class = '',
      the_id    = '',
      css_style = '',
      &block
    )
    HtmlTags.div(i, css_class, the_id, css_style, &block)
  end

  # ========================================================================= #
  # === a                                                             (a tag)
  # ========================================================================= #
  def a(
      i          = '',
      css_class  = '',
      the_id     = '',
      css_style  = '',
      javascript = '',
      &block
    )
    HtmlTags.a(
      i, css_class, the_id, css_style, javascript, &block
    )
  end

  # ========================================================================= #
  # === form                                                       (form tag)
  # ========================================================================= #
  def form(
      i          = '',
      css_class  = '',
      the_id     = '',
      css_style  = '',
      &block
    )
    HtmlTags.form(
      i, css_class, the_id, css_style, &block
    )
  end

  # ========================================================================= #
  # === br
  # ========================================================================= #
  def br
    HtmlTags.br
  end

  # ========================================================================= #
  # === html
  # ========================================================================= #
  def html(
      i               = '',
      css_class       = '',
      the_id          = '',
      css_style       = '',
      &block
    )
    HtmlTags.html(i, css_class, the_id, css_style, &block)
  end

end; end