#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'html_tags/closing_tag/closing_tag.rb'
# =========================================================================== #
module HtmlTags

  require 'html_tags/toplevel_methods/strip_newlines.rb'
  # ========================================================================= #
  # === HtmlTags.close
  #
  # This method creates the closing tag. It will return that tag as
  # a string.
  #
  # This method also accepts a block, which can be a hash that could
  # have keys such as { :make_newline => true }.
  #
  # Usage example:
  #
  #   HtmlTags.close('span')
  #
  # ========================================================================= #
  def self.close(i, &block)
    append_newline = true
    # ======================================================================= #
    # If we strip newlines, then we won't append them logically.
    # ======================================================================= #
    append_newline = false if HtmlTags.strip_newlines?
    i = i.to_s.dup # It should remain a String.
    # ======================================================================= #
    # Next, sanitize some wrongful/shortcut tags here.
    # ======================================================================= #
    case i
    when 'link'
      i = 'a'
    when 'field',
         'mini_header'
      i = 'fieldset'
    end
    end_string = ''.dup # This will be be appended.
    # ======================================================================= #
    # Intercept blocks passed to the method here.
    # ======================================================================= #
    if block_given?
      yielded = yield # Tap into the block.
      if yielded.is_a? Hash
        if yielded.has_key? :make_newline
          end_string << br if yielded[:make_newline] == true
        end
      elsif yielded == :make_newline
        end_string << br
      elsif yielded == :no_newline
        append_newline = false # Do not append a newline in this case here.
      end
    end
    result = ''.dup
    result << "\n" if append_newline
    result << '</'+i.to_s.dup+'>'
    result << "\n" if append_newline
    result << end_string # This is the result we will return. A String.
    return result
  end

  # ========================================================================= #
  # === close                                                     (close tag)
  #
  # This is a wrapper towards HtmlTags.close(), which will close a
  # given HTML tag.
  # ========================================================================= #
  def close(i, &block)
    return HtmlTags.close(i, &block) # Delegate to the above class-method.
  end; alias ctag close # === ctag
       # alias c close <- Not sure about that alias yet.

end