#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === HtmlTags
#
# This project can generate HTML tags. We will also create the corresponding
# closing tags to said actions - see the file html_closing_tags.rb for
# close-related actions.
#
# If you want to autoinclude this project, do this:
#   require 'html_tags/autoinclude'
# =========================================================================== #
require 'pathname'
require 'html_tags/array_registered_html_tags.rb' # bl $HTML_TAGS/array_registered_html_tags.rb
require 'html_tags/constants/array_strip_newlines.rb'
require 'html_tags/constants.rb'
require 'html_tags/html_closing_tags.rb'
require 'html_tags/html_comment.rb'
require 'html_tags/html_tags_constants.rb'
require 'html_tags/opening_tag/opening_tag.rb'
require 'html_tags/shared.rb'
require 'html_tags/stag.rb'
require 'html_tags/version/version.rb'
require 'html_tags/toplevel_methods/full_output.rb'
require 'html_tags/toplevel_methods/strip_newlines.rb'

# =========================================================================== #
# Next, require the individual tags from the individual_tags/ directory.
# =========================================================================== #
Dir[RbConfig::CONFIG['sitelibdir']+'/html_tags/individual_tags/*.rb'].each {|file|
  require file
}

module HtmlTags # require 'html_tags'

  include HtmlTags::Shared

  # ========================================================================= #
  # === NL
  # ========================================================================= #
  NL = "\n"

  # ========================================================================= #
  # === is_this_an_allowed_tag_in_head_element?
  #
  # This method will return true or false depending on whether the given
  # tag may be part of a <head> tag.
  # ========================================================================= #
  def is_this_an_allowed_tag_in_head_element?(i)
    i = i.to_s # Ought to be a String.
    # ======================================================================= #
    # Get rid of <> tags.
    # ======================================================================= #
    i.delete!('<')
    i.delete!('>')
    VALID_TAGS_IN_A_HEAD_TAG.include? i
  end

  # ========================================================================= #
  # === fieldset
  # ========================================================================= #
  def fieldset(
      i = '', css_class = '', the_id = '', css_style = ''
    )
    return HtmlTags.add(
      opening_tag(__method__, css_class, the_id, css_style)+
      i.to_s+
      close(__method__)
    )
  end

  # ========================================================================= #
  # === q
  #
  # The quote tag, <q>.
  # ========================================================================= #
  def q(i = '', css_class = '', the_id = '', css_style = '')
    return HtmlTags.add(
      opening_tag(__method__, css_class, the_id, css_style)+
      i.to_s+
      close(__method__)
    )
  end; alias quote q # === quote

  # ========================================================================= #
  # === hr
  # ========================================================================= #
  def hr
    return HtmlTags.add(
      otag(__method__)
    )
  end

  # ========================================================================= #
  # === sbody
  #
  # Start of body tag.
  # ========================================================================= #
  def sbody
    unless string?.include?('</head>')
      HtmlTags.add('</head><body>')
    end
  end

  extend self

end

# =========================================================================== #
# Now some testing of the HTML components:
# =========================================================================== #
if __FILE__ == $PROGRAM_NAME
  include HtmlTags
  puts li 'Hi there.'
  puts 'Now testing some components:'
  ARRAY_REGISTERED_HTML_TAGS.each {|entry|
    puts send(entry.to_sym)
  }
  puts head {'Ok'}
  puts button 'ack','s1em'
  ARRAY_REGISTERED_HTML_TAGS.each {|entry|
    begin
      puts send(entry.to_sym, 'Test','bblack1')
    rescue Exception => error
      pp error
    end
  }
  puts h4 'Test','bblack1'
  puts h4 'Test','bblack1','foo','border:1px solid black'
end # htmltags