#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# Documentation for the <figure> tag can be viewed here:
#
#   https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figure
#
# The HTML <figure> Element represents self-contained content, frequently
# with a caption (<figcaption>), and is typically referenced as a single
# unit. While it is related to the main flow, its position is independent
# of the main flow.
#
# Usually this is an image, an illustration, a diagram, a code snippet, or
# a schema that is referenced in the main text, but that can be moved to
# another page or to an appendix without affecting the main flow.
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === figure
  #
  # To test this, try:
  #
  #   include HtmlTags; figure '<img src="/home/x/DATA/IMG/FOTOS/CATS/03.09.2003_Babykatze.jpg" alt="An awesome picture">	
	#   <figcaption>Aisha ist noch immer mde, und sehr, sehr satt.</figcaption>'
	#
  # ========================================================================= #
  def figure(
      i = '', css_class = '', the_id = '', css_style = ''
    )
    return HtmlTags.add(
      opening_tag(__method__, css_class, the_id, css_style)+
      i.to_s+
      close(__method__)
    )
  end

end