#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === form
  #
  # This method will generate a HTML <form> tag, ultimately. The form tag
  # is used for user-generated content, such as during a POST action
  # during a HTTP communication.
  #
  # The HTML <form> element only supports GET and POST as available actions.
  #
  # Do note that a <form> tag is a bit more complicated than, say,
  # a <div> tag or a <p> tag, because we may need to attach additional
  # information towards the <form> tag, such as "id", "name" or "action"
  # entries.
  #
  # Invocation examples:
  #
  #   form(css_style: 'margin-left:2em; margin-top:2px'){
  #   form(action: 'bla.cgi', name: 'some_name', css_style: 'margin-left:2em; margin-top:2px'){
  #
  # ========================================================================= #
  def form(
      i         = '',
      css_class = '',
      the_id    = '',
      css_style = '',
      &block
    )
    # ======================================================================= #
    # === Handle Hashes as input given
    # ======================================================================= #
    if i.is_a? Hash
      # ===================================================================== #
      # === :action
      #
      # :action is presently not implemented.
      # ===================================================================== #
      # if i.has_key? :action
      # end
      # ===================================================================== #
      # === :css_style
      # ===================================================================== #
      if i.has_key? :css_style
        css_style = i.delete(:css_style)
      end
    end
    the_opening_tag = opening_tag(
      __method__, css_class, the_id, css_style
    )
    # ======================================================================= #
    # Next, add ad-hoc support for "id", "name" and "action".
    # ======================================================================= #
    if i.is_a? Hash
      if i.has_key? :id
        the_opening_tag[the_opening_tag.index('>'),0] = ' id="'+i.delete(:id).to_s+'"'
      end
      if i.has_key? :action
        the_opening_tag[the_opening_tag.index('>'),0] = ' action="'+i.delete(:action).to_s+'"'
      end
      if i.has_key? :name
        the_opening_tag[the_opening_tag.index('>'),0] = ' name="'+i.delete(:name).to_s+'"'
      end
      if i.has_key? :method
        the_opening_tag[the_opening_tag.index('>'),0] = ' method="'+i.delete(:method).to_s+'"'
      end
      # ===================================================================== #
      # Finally, if that hash is empty, turn it into an empty String.
      # ===================================================================== #
      if i.is_a?(Hash) and i.empty?
        i = ''.dup
      end
    end
    # ======================================================================= #
    # Past the next step, the variable `i` will be guaranted to be a String.
    # ======================================================================= # 
    i = i.to_s
    if block_given?
      yielded = "#{yield}"
      i << yielded
    end
    return HtmlTags.add(
      the_opening_tag+
      i+
      close(__method__)
    )
  end

end