#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === html
  #
  # A <html> tag in HTML5 may have some attributes such as:
  #
  #   <html lang="en">
  #
  # See http://www.w3schools.com/tags/ref_language_codes.asp for more
  # information pertaining to the <html> tag.
  #
  # For now, we will use lang="en" all the time.
  #
  # To test this standalone, try:
  #
  #   HtmlTags.html
  #
  # ========================================================================= #
  def html(
      i         = '',
      css_class = '',
      the_id    = '',
      css_style = '',
      &block
    )
    opening = HtmlTags.open_html # Delegate to the method below.
    _ = ''.dup
    if block_given?
      yielded = yield
      case yielded
      when :use_unicode_as_encoding
        opening << "<meta charset=\"UTF-8\">\n"
      else
        _ << yielded
      end
    end
    return HtmlTags.add(
      opening+
      i.to_s+
      _.to_s+
      close(__method__)
    )
  end

  # ========================================================================= #
  # === HtmlTags.open_html
  #
  # We will automatically append lang="en" to the tag.
  # ========================================================================= #
  def self.open_html
    opening = opening_tag(:html)
    opening[-2,0] = ' lang="en"'
    opening
  end

end