module HtmlTags

  # ========================================================================= #
  # === label
  #
  # The html <label> tag is useful to specify text before an <input>
  # field.
  #
  # The <label> tag defines a label for an <input> element.
  #
  # The <label> element does not render as anything special for the
  # user. However, it provides a usability improvement for mouse
  # users, because if the user clicks on the text within the <label>
  # element, it toggles the control.
  #
  # The "for" attribute of the <label> tag should be equal to the id
  # attribute of the related element to bind them together.
  #
  # This may be best explained through an example:
  #
  #   <label for="male">Male</label>
  #   <input type="radio" name="sex" id="male" value="male">
  #
  # Documentation can be seen here:
  #   http://www.w3schools.com/tags/tag_label.asp
  # ========================================================================= #
  def label(
      i         = '',
      css_class = '',
      the_id    = '',
      css_style = ''
    )
    start = opening_tag(__method__, css_class, the_id, css_style)
    for_label = i.to_s.downcase.strip # Right now the for-label is deduced from the input.
    start[-2,0] = ' for="'+for_label+'"' # -2 because we also have a trailing newline.
    return HtmlTags.add(
      start+
      i.to_s+
      close(__method__)
    )
  end

end