#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === ol                                                           (ol tag)
  #
  # This is essentially a HTML representation for the <ol> tag.
  #
  # The <ol> tag defines an ordered list. An ordered list can be
  # either numerical or it can be alphabetical.
  #
  # The <li> tag can be used to define list items.
  #
  # Documentation for the <ol> tag can be seen here:
  #
  #   https://www.w3schools.com/tags/tag_ol.asp
  #
  # ========================================================================= #
  def ol(
      i                   = '', # <- This is the content.
      css_class           = '',
      the_id              = '',
      css_style           = '',
      optional_javascript = '',
      &block
    )
    if i.is_a? Hash
      if i.has_key? :css_class
        css_class = i.delete(:css_class)
      end
      i = ''
    end
    i = i.to_s.dup # And avoid frozen-errors.
    # ======================================================================= #
    # Blocks will be assumed to be used for the first argument, `i`.
    # ======================================================================= #
    if block_given?
      i << yield.to_s
    end
    return HtmlTags.add(
      opening_tag(__method__, css_class, the_id, css_style, optional_javascript)+
      i+
      close(__method__)
    )
  end

end