#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === span
  #
  # This method will generate HTML <span> tags.
  #
  # It will first invoke the method called opening_tag(), then add
  # the content that was given to it (the first parameter), and then
  # close the whole tag via the close() method.
  #
  # Do note that you can eliminate newlines by invoking the method
  # in something like this, via :strip:
  #
  #   HtmlTags.span('Hello world!','s1') { :strip }
  #   HtmlTags.span(i, css_class: 'bord1px', css_style: 'margin-left: 1em')
  #
  # ========================================================================= #
  def span(
      i          = '',
      css_class  = '',
      the_id     = '',
      css_style  = '',
      javascript = '',
      &block
    )
    i = i.to_s
    start_the_method = opening_tag(
                         __method__,
                         css_class,
                         the_id,
                         css_style,
                         javascript
                       )
    close_the_method = close(__method__)
    if block_given?
      yielded = yield
      case yielded
      when :strip
        # Unfreeze, if frozen:
        i = i.dup if i.frozen?
        close_the_method = close_the_method.dup if close_the_method.frozen?
        start_the_method = start_the_method.dup if start_the_method.frozen?
        i.strip!
        close_the_method.strip!
        start_the_method.strip!
      end
    end
    return HtmlTags.add(
      start_the_method+
      i+
      close_the_method
    )
  end; alias s2 span

end