#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === textarea
  #
  # Do note that the <textarea> tag also has an entry called spellcheck.
  #
  # Example:
  #
  #   <textarea spellcheck="true"></textarea>
  #
  # This appears to be true by default on palemoon, firefox and chrome,
  # but I am not sure that it is too terribly useful, so as far as the
  # HtmlTags project is concerned, it will be set to false by default.
  #
  # Invocation example:
  #
  #   HtmlTags.textarea('Hello world!') # => <textarea spellcheck="true">Hello world!</textarea>
  #
  # ========================================================================= #
  def textarea(
      i          = '',
      css_class  = '',
      the_id     = '',
      css_style  = '',
      spellcheck = false
    )
    start = opening_tag(__method__, css_class, the_id, css_style)
    index = start.index('textarea>')+'textarea>'.size - 1
    if spellcheck
      start[index,0] = ' spellcheck="true"'
    else
      start[index,0] = ' spellcheck="false"'
    end
    return HtmlTags.add(
      start+
      i.to_s+
      close(__method__)
    )
  end

end