#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'html_tags/opening_tag/opening_tag.rb'
# =========================================================================== #
module HtmlTags

  begin
    require 'web_object/requires/require_web_images.rb'
  rescue LoadError; end

  require 'html_tags/array_registered_html_tags.rb'
  require 'html_tags/closing_tag/closing_tag.rb'

  # ========================================================================= #
  # === HtmlTags.opening_tag                                (opening_tag tag)
  #
  # If we pass a block to this method, we treat it as a special hash.
  #
  # This can be used to make use of src.
  #
  # Note that arguments to this method can become quite complicated.
  #
  # For instance, consider this here:
  #
  #   e p 'Good Bye', :css_class => 'border: 1px solid red',
  #                   :id        => 'goodbye'
  #
  # ========================================================================= #
  def self.opening_tag(
      i, # The name of the tag comes here.
      optional_css_class  = '', # 2nd parameter
      optional_the_id     = '', # 3rd parameter
      optional_css_style  = '', # 4th parameter
      optional_javascript = '', # 5th parameter
      &block
    )
    append_newline = true
    i = i.to_s.dup # Must use .dup here, to prevent cascading string-taint.
    original_tag_name = i.to_s.dup
    case i
    when 's','' # Sanitize in these two cases.
      i = 'span'
    end
    content = ''.dup # This here will be appended always.
    end_string = ''.dup
    i = i.dup if i.frozen?
    # ======================================================================= #
    # === optional_css_class
    #
    # Next we must intercept when the second argument is a Hash.
    # ======================================================================= #
    if optional_css_class.is_a? Hash
      if optional_css_class.has_key? :id
        optional_the_id = optional_css_class.delete(:id)
      end
      # ===================================================================== #
      # === :css_style
      # ===================================================================== #
      if optional_css_class.has_key? :css_style
        optional_css_style = optional_css_class.delete(:css_style)
      # ===================================================================== #
      # === :style
      # ===================================================================== #
      elsif optional_css_class.has_key? :style
        optional_css_style = optional_css_class.delete(:style)
      end
      # ===================================================================== #
      # Intercept javascript keys. Several aliases could be used, so
      # we have to check for them.
      # ===================================================================== #
      if    optional_css_class.has_key? :javascript
        optional_javascript = optional_css_class.delete(:javascript)
      elsif optional_css_class.has_key? :javascript_code
        optional_javascript = optional_css_class.delete(:javascript_code)
      elsif optional_css_class.has_key? :desc
        content << optional_css_class.delete(:desc).to_s
      end
      if optional_css_class.has_key? :css_class # This here must come last.
        optional_css_class = optional_css_class.delete(:css_class).to_s.dup
      elsif optional_css_class.has_key? :title
        i << ' title="'+optional_css_class.delete(:title).to_s+'"'
        optional_css_class = ''
      end
      if optional_css_class.empty?
        optional_css_class = ''
      end if optional_css_class.is_a? Hash
    end
    # ======================================================================= #
    # === optional_javascript
    #
    # Intercept optional_javascript if it is a Hash.
    # ======================================================================= #
    if optional_javascript.is_a? Hash
      if optional_javascript.has_key? :on_click # Redirect
        optional_javascript[:onclick] = optional_javascript.delete(:on_click)
      end
      if optional_javascript.has_key? :onclick
        js_temp_string  = optional_javascript[:onclick].to_s
        if js_temp_string.include? 'background-color'
          optional_javascript = 'onclick="set_background_color('+
            js_temp_string.gsub(/background-color\:/,'').delete(';')+
            ', this)"'
        elsif js_temp_string == 'go back in history' # Sanitize it.
          optional_javascript = 'history.back(-1)'
        end
      elsif optional_javascript.has_key? :javascript_hover
        # The following code works on:
        #   :javascript_hover => 'color: lightblue'
        js_temp_string  = optional_javascript[:javascript_hover].to_s
        if js_temp_string.include? 'color'
          optional_javascript = ' onmouseover="colourize(this, '+
            js_temp_string.gsub(/color\:/,'').to_s.delete(' ')+')"'
        end
      end
    # ======================================================================= #
    # Next handle special String-input given to the javascript component.
    # ======================================================================= #
    elsif optional_javascript.is_a? String
      if optional_javascript.include?('on_click:') # Input may be: 'on_click: show_image(:axe))'
        if optional_javascript.frozen?
          optional_javascript = optional_javascript.dup
        end
        optional_javascript.gsub!(/on_click: /, '')
        if optional_javascript.include? 'show_image'
          optional_javascript =~ /\((.+)\)/
          optional_javascript = $1.to_s.dup.delete(')')
          optional_javascript = WebObject.obtain(optional_javascript)
          optional_javascript = 'onclick="reveal('+"'"+optional_javascript+"'"+')"'
        end
      end
    end
    # ======================================================================= #
    # Next we require the four input-objects to be Strings.
    # ======================================================================= #
    optional_css_class  = optional_css_class.to_s.dup
    optional_the_id     = optional_the_id.to_s
    case optional_css_style
    when :bold
      # ===================================================================== #
      # === Intercept key :bold next
      #
      # This is a special key in the sense that we will "translate" it
      # into the corresponding CSS value. So :bold really just means
      # to be replaced with the string 'font-weight: bold'.
      # ===================================================================== #
      optional_css_style = 'font-weight: bold;'
    end
    optional_css_style  = optional_css_style.to_s
    optional_javascript = optional_javascript.to_s

    if optional_css_style.include? "\n" # Get rid of newlines and multiple ' '.
      optional_css_style = beautify_string(optional_css_style)
    end
    # ======================================================================= #
    # === Handle blocks next
    #
    # Intercept blocks passed to this method. Typically blocks will,
    # in some form, be appended to the opening-tag at hand.
    # ======================================================================= #
    if block_given? # If we passed a block
      yielded = yield # Tap into the block.
      if yielded.is_a? Hash
        # =================================================================== #
        # === :src
        # =================================================================== #
        if yielded.has_key? :src
          i << ' src="'+yielded.delete(:src).to_s+'"'
        end
        # =================================================================== #
        # === :href
        # =================================================================== #
        if yielded.has_key? :href
          i << ' href="'+yielded.delete(:href).to_s+'"'
        end
        # =================================================================== #
        # === :type
        # =================================================================== #
        if yielded.has_key? :type
          i << ' type="'+yielded.delete(:type).to_s+'"'
        end
        # =================================================================== #
        # === :value
        #
        # This entry point should come after :type, as I think it looks
        # a bit prettier that way.
        # =================================================================== #
        if yielded.has_key? :value
          i << ' value="'+yielded.delete(:value).to_s+'"'
        end
        # =================================================================== #
        # === :link_description or :description
        # =================================================================== #
        if yielded.has_key?(:link_description) or
           yielded.has_key?(:description) or
           yielded.has_key?(:content)
          # if content.empty? # We only append to content if is empty. Disabled this in Jun 2015.
            if yielded.has_key?    :link_description
              content << yielded.delete(:link_description).to_s
            elsif yielded.has_key? :description
              content << yielded.delete(:description).to_s
            elsif yielded.has_key? :content
              content << yielded.delete(:content).to_s
            end
          #end
        # =================================================================== #
        # === :desc
        # =================================================================== #
        elsif yielded.has_key? :desc
          content << yielded.delete(:desc).to_s
        end
        # =================================================================== #
        # === :make_newline
        # =================================================================== #
        if yielded.has_key? :make_newline
          end_string << br
        end
      # ===================================================================== #
      # === Handle Symbols directly past this point
      # ===================================================================== #
      elsif yielded.is_a? Symbol 
        case yielded
        when :no_newline
          append_newline = false
        end
      end
    end
    # ======================================================================= #
    # Next, add the class, id, style, and javascript entries to our tag.
    # ======================================================================= #
    i << ' class="'+optional_css_class+'"' unless optional_css_class.empty?
    i << ' id="'+optional_the_id+'"'       unless optional_the_id.empty?
    i << ' style="'+optional_css_style+'"' unless optional_css_style.empty?

    unless optional_javascript.empty?
      # ===================================================================== #
      # Always prepend ' ' if it is not empty.
      # ===================================================================== #
      if optional_javascript.frozen?
        optional_javascript = optional_javascript.dup
      end
      optional_javascript.prepend ' '
      # ===================================================================== #
      # Add some exceptions: currently the exceptions include
      # "onclick" and "onmouse".
      # ===================================================================== #
      unless optional_javascript.strip.start_with?('onclick') or
             optional_javascript.strip.start_with?('onmouse')
        optional_javascript = 'javascript="'+optional_javascript+'"'
      end
      i << optional_javascript
    end
    # ======================================================================= #
    # === Append '/' to a few tags.
    # ======================================================================= #
    if ARRAY_TAGS_WITHOUT_CLOSING_TAG.include? original_tag_name
      i << '/' # Add exception for <br/> tags and some others.
    end
    i = "<#{i}>#{end_string}"
    i = i.dup if i.frozen?
    i << "\n" if append_newline
    i << content
    return i
  end; self.instance_eval { alias otag opening_tag } # === HtmlTags.otag

  # ========================================================================= #
  # === opening_tag
  # ========================================================================= #    
  def opening_tag(
      i,
      optional_css_class  = '',
      optional_the_id     = '',
      optional_css_style  = '',
      optional_javascript = ''
    )
    HtmlTags.opening_tag(i,
      optional_css_class,
      optional_the_id,
      optional_css_style,
      optional_javascript
    ) 
  end; alias otag opening_tag # === otag

end