#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
module HtmlTags

  # ========================================================================= #
  # === stag
  #
  # This method returns a proper HTML tag, including css class, possible
  # javascript, id, and css style, and then return this as a string.
  #
  # By default we will use the <span> tag, hence why we have assigned
  # the default argument "span" as the first argument to this method.
  #
  # "stag" is an alias to this method, a shortcut for "string_tag".
  #
  # Note that stag() itself will not return the closing tag.
  #
  # Specific Usage Examples for this method:
  #
  #   HtmlTags.stag('span','marl1em')
  #   puts HtmlTags.stag('span','','','margin-left:0.92em; padding-left:6px')
  #
  # Would return:
  #
  #   <span class="marl1em">
  #
  # ========================================================================= #
  def stag(
        name_of_the_tag     = 'span',
        optional_css_class  = '',
        optional_the_id     = '',
        optional_css_style  = '',
        optional_javascript = '',
        &block
      )
    if optional_css_class.is_a? Hash
      _ = otag(name_of_the_tag, optional_css_class) # otag() is defined in opening_tag.rb
    else # We assume a string here.
      optional_css_class = optional_css_class.to_s.chomp.dup
      _ = otag(
        name_of_the_tag,
        css_class:  optional_css_class,
        id:         optional_the_id,
        css_style:  optional_css_style,
        javascript: optional_javascript,
        &block
      )
    end
    _.to_s
  end; alias string_tag stag # === string_tag

end